Skip to contents

Extracts the suit of each card in the card_vector.

Usage

card_suit(x)

Arguments

x

A card_vector object.

Value

A character vector containing the suits of the cards.

Examples

# Extract card suits from a deck
deck <- card_vector(c("A♠", "10♣", "K♥"))
card_suit(deck)
#> [1] "♠" "♣" "♥"